mx: Example of spatial polygon for a region of interest

mxR Documentation

Example of spatial polygon for a region of interest

Description

An object of class SpatVector.

Format

SpatVector

Examples

mx <- terra::vect(system.file("extdata/mx.gpkg", package = "biosurvey"))

mx

claununez/biosurvey documentation built on April 25, 2024, 12:24 a.m.