| save_PAM | R Documentation |
Functions to save and read PAM objects
save_PAM(PAM, file_name, verbose = TRUE)
read_PAM(file_name)
PAM |
object of class base_PAM or PAM_subset derived from the functions
|
file_name |
(character) name for the file to save or read the PAM object (includes extension ".rds"). |
verbose |
whether or not to print messages about the process. Default = TRUE. |
If verbose = TRUE, a message indicating the path where the object
was saved.
an object of class base_PAM with its spatial object unwrapped.
b_pam <- read_PAM(system.file("extdata/b_pam.rds",
package = "biosurvey"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.